@@ -1,8 +1,15 @@
+'''
+Initialize Covasim by importing all the modules
+
+Convention is to use "import covasim as cv", and then to use all functions and
+classes directly, e.g. cv.Sim() rather than cv.sim.Sim().
+'''
+
 # Check that requirements are met and set options
 from . import requirements
 from .settings import *
 
-# Import the version and print the license unless verbosity is disabled
+# Import the version and print the license unless verbosity is disabled, via e.g. os.environ['COVASIM_VERBOSE'] = 0
 from .version import __version__, __versiondate__, __license__
 if settings.options.verbose:
     print(__license__)
@@ -21,3 +28,5 @@ from .immunity      import * # Depends on utils, parameters, defaults
 from .analysis      import * # Depends on utils, misc, interventions
 from .sim           import * # Depends on almost everything
 from .run           import * # Depends on sim
+
+
