@@ -20,7 +20,6 @@ import covasim as cv
 
 # Set environment
 os.environ['SPHINX_BUILD'] = 'True' # This is used so cv.options.set('jupyter') doesn't reset the Matplotlib renderer
-os.environ['COVASIM_WARNINGS'] = 'error' # Don't let warnings pass in the tutorials
 on_rtd = os.environ.get('READTHEDOCS') == 'True'
 
 if sys.platform in ["linux", "darwin"]:
@@ -96,13 +95,6 @@ version = cv.__version__
 # The full version, including alpha/beta/rc tags.
 release = cv.__version__
 
-# The language for content autogenerated by Sphinx. Refer to documentation
-# for a list of supported languages.
-#
-# This is also used if you do content translation via gettext catalogs.
-# Usually you set "language" from the command line for these cases.
-language = None
-
 # List of patterns, relative to source directory, that match files and
 # directories to ignore when looking for source files.
 # This patterns also effect to html_static_path and html_extra_path
